@@ -1,6 +1,6 @@
 import logging
 import os
-from typing import Any, Dict
+from typing import Any
 
 from erdpy import cli_shared, errors, projects, utils
 from erdpy.accounts import Account, Address
@@ -29,6 +29,9 @@ def setup_parser(subparsers: Any) -> Any:
     _add_project_arg(sub)
     sub.add_argument("--debug", action="store_true", default=False, help="set debug flag (default: %(default)s)")
     sub.add_argument("--no-optimization", action="store_true", default=False, help="bypass optimizations (for clang) (default: %(default)s)")
+    sub.add_argument("--cargo-target-dir", type=str, help="for rust projects, forward the parameter to Cargo")
+    sub.add_argument("--wasm-symbols", action="store_true", default=False, help="for rust projects, does not strip the symbols from the wasm output. Useful for analysing the bytecode. Creates larger wasm files. Avoid in production (default: %(default)s)")
+    sub.add_argument("--wasm-name", type=str, help="for rust projects, optionally specify the name of the wasm bytecode output file")
     sub.set_defaults(func=build)
 
     sub = cli_shared.add_command_subparser(subparsers, "contract", "clean", "Clean a Smart Contract project.")
@@ -61,7 +64,11 @@ def setup_parser(subparsers: Any) -> Any:
     cli_shared.add_tx_args(sub, with_receiver=False, with_data=False)
     _add_function_arg(sub)
     _add_arguments_arg(sub)
-    cli_shared.add_broadcast_args(sub)
+    sub.add_argument("--wait-result", action="store_true", default=False,
+                     help="signal to wait for the transaction result - only valid if --send is set")
+    sub.add_argument("--timeout", default=100, help="max num of seconds to wait for result"
+                                                    " - only valid if --wait-result is set")
+    cli_shared.add_broadcast_args(sub, relay=True)
 
     sub.set_defaults(func=call)
 
@@ -139,7 +146,10 @@ def build(args: Any):
     options = {
         "debug": args.debug,
         "optimized": not args.no_optimization,
-        "verbose": args.verbose
+        "verbose": args.verbose,
+        "cargo_target_dir": args.cargo_target_dir,
+        "wasm_symbols": args.wasm_symbols,
+        "wasm_name": args.wasm_name
     }
 
     projects.build_project(project, options)
@@ -286,9 +296,17 @@ def query(args: Any):
 
 
 def _send_or_simulate(tx: Transaction, args: Any):
-    if args.send:
+    send_wait_result = args.wait_result and args.send and not args.simulate
+    send_only = args.send and not (args.wait_result or args.simulate)
+    simulate = args.simulate and not (send_only or send_wait_result)
+
+    if send_wait_result:
+        proxy = ElrondProxy(args.proxy)
+        response = tx.send_wait_result(proxy, args.timeout)
+        return None
+    elif send_only:
         tx.send(ElrondProxy(args.proxy))
         return None
-    elif args.simulate:
+    elif simulate:
         response = tx.simulate(ElrondProxy(args.proxy))
         return response
