@@ -13,8 +13,12 @@ def setup_parser(subparsers: Any) -> Any:
     sub = cli_shared.add_command_subparser(subparsers, "tx", "new", "Create a new transaction")
     _add_common_arguments(sub)
     cli_shared.add_outfile_arg(sub, what="signed transaction, hash")
-    cli_shared.add_broadcast_args(sub)
+    cli_shared.add_broadcast_args(sub, relay=True)
     cli_shared.add_proxy_arg(sub)
+    sub.add_argument("--wait-result", action="store_true", default=False,
+                     help="signal to wait for the transaction result - only valid if --send is set")
+    sub.add_argument("--timeout", default=100, help="max num of seconds to wait for result"
+                                                    " - only valid if --wait-result is set")
     sub.set_defaults(func=create_transaction)
 
     sub = cli_shared.add_command_subparser(subparsers, "tx", "send", "Send a previously saved transaction")
@@ -26,6 +30,7 @@ def setup_parser(subparsers: Any) -> Any:
     sub = cli_shared.add_command_subparser(subparsers, "tx", "get", "Get a transaction")
     sub.add_argument("--hash", required=True, help="the hash")
     sub.add_argument("--sender", required=False, help="the sender address")
+    sub.add_argument("--with-results", action="store_true", help="will also return the results of transaction")
     cli_shared.add_proxy_arg(sub)
     cli_shared.add_omit_fields_arg(sub)
     sub.set_defaults(func=get_transaction)
@@ -51,14 +56,22 @@ def create_transaction(args: Any):
 
     tx = do_prepare_transaction(args)
 
-    if args.relay:
+    if hasattr(args, "relay") and args.relay:
         args.outfile.write(tx.serialize_as_inner())
         return
 
+    send_wait_result = args.wait_result and args.send and not args.simulate
+    send_only = args.send and not (args.wait_result or args.simulate)
+    simulate = args.simulate and not (send_only or send_wait_result)
+
     try:
-        if args.send:
+        if send_wait_result:
+            proxy = ElrondProxy(args.proxy)
+            response = tx.send_wait_result(proxy, args.timeout)
+            utils.dump_out_json(response)
+        elif send_only:
             tx.send(ElrondProxy(args.proxy))
-        elif args.simulate:
+        elif simulate:
             response = tx.simulate(ElrondProxy(args.proxy))
             utils.dump_out_json(response)
     finally:
@@ -82,6 +95,6 @@ def get_transaction(args: Any):
 
     proxy = ElrondProxy(args.proxy)
 
-    transaction = proxy.get_transaction(args.hash, args.sender)
+    transaction = proxy.get_transaction(args.hash, args.sender, args.with_results)
     utils.omit_fields(transaction, omit_fields)
     utils.dump_out_json(transaction)
