@@ -20,6 +20,10 @@ class MetaChainSystemSCsCost:
     CHANGE_REWARD_ADDRESS = 5000000
     CHANGE_VALIDATOR_KEYS = 5000000
     UNJAIL = 5000000
+    DELEGATION_MANAGER_OPS = 50000000
+    DELEGATION_OPS = 1000000
+    UNSTAKE_TOKENS = 5000000
+    UNBOND_TOKENS = 5000000
 
 
 def get_proxy() -> str:
@@ -49,14 +53,55 @@ def get_dependency_url(key: str, tag: str, platform: str) -> str:
 
 def get_value(name: str) -> str:
     _guard_valid_name(name)
-    data = read_file()
+    data = get_active()
     return data.get(name, get_defaults()[name])
 
 
 def set_value(name: str, value: Any):
     _guard_valid_name(name)
     data = read_file()
-    data[name] = value
+    active_config = data.get("active", "default")
+    data.setdefault("configurations", {})
+    data["configurations"].setdefault(active_config, {})
+    data["configurations"][active_config][name] = value
+    write_file(data)
+
+
+def get_active():
+    data = read_file()
+    configs = data.get("configurations", {})
+    active_config = data.get("active", "default")
+
+    return configs.get(active_config, {})
+
+
+def set_active(name: str):
+    data = read_file()
+    _guard_valid_config_name(data, name)
+    data["active"] = name
+    write_file(data)
+
+
+def create_new_config(name: str, template: str):
+    data = read_file()
+    _guard_config_unique(data, name)
+    new_config = {}
+    if template is not None and template != "":
+        _guard_valid_config_name(data, template)
+        new_config = data["configurations"][template]
+
+    data["active"] = name
+    data.setdefault('configurations', {})
+    data["configurations"][name] = new_config
+    write_file(data)
+
+
+def delete_config(name: str):
+    _guard_valid_config_deletion(name)
+    data = read_file()
+    data["configurations"].pop(name, None)
+    if data["active"] == name:
+        data["active"] = "default"
     write_file(data)
 
 
@@ -65,14 +110,31 @@ def _guard_valid_name(name: str):
         raise errors.UnknownConfigurationError(name)
 
 
+def _guard_valid_config_name(config: Any, name: str):
+    configurations = config.get('configurations', {})
+    if name not in configurations:
+        raise errors.UnknownConfigurationError(name)
+
+
+def _guard_config_unique(config: Any, name: str):
+    configurations = config.get('configurations', {})
+    if name in configurations:
+        raise errors.ConfigurationShouldBeUniqueError(name)
+
+
+def _guard_valid_config_deletion(name: str):
+    if name == "default":
+        raise errors.ConfigurationProtectedError(name)
+
+
 def get_defaults() -> Dict[str, Any]:
     return {
-        "proxy": "https://api-testnet.elrond.com",
+        "proxy": "https://testnet-gateway.elrond.com",
         "chainID": "T",
         "txVersion": "1",
-        "dependencies.arwentools.tag": "v0.4.1",
-        "dependencies.arwentools.urlTemplate.linux": "https://ide.elrond.com/travis-builds/ARWEN_{TAG}_linux_amd64.tar.gz",
-        "dependencies.arwentools.urlTemplate.osx": "https://ide.elrond.com/travis-builds/ARWEN_{TAG}_darwin_amd64.tar.gz",
+        "dependencies.arwentools.tag": "v1.1.2",
+        "dependencies.arwentools.urlTemplate.linux": "https://github.com/ElrondNetwork/arwen-wasm-vm/archive/{TAG}.tar.gz",
+        "dependencies.arwentools.urlTemplate.osx": "https://github.com/ElrondNetwork/arwen-wasm-vm/archive/{TAG}.tar.gz",
         "dependencies.llvm.tag": "v9-19feb",
         "dependencies.llvm.urlTemplate.linux": "https://ide.elrond.com/vendor-llvm/{TAG}/linux-amd64.tar.gz?t=19feb",
         "dependencies.llvm.urlTemplate.osx": "https://ide.elrond.com/vendor-llvm/{TAG}/darwin-amd64.tar.gz?t=19feb",
@@ -93,7 +155,7 @@ def get_defaults() -> Dict[str, Any]:
         "dependencies.mcl_signer.tag": "v1.0.0",
         "dependencies.mcl_signer.urlTemplate.linux": "https://github.com/ElrondNetwork/elrond-sdk-go-tools/releases/download/{TAG}/mcl_signer_{TAG}_ubuntu-latest.tar.gz",
         "dependencies.mcl_signer.urlTemplate.osx": "https://github.com/ElrondNetwork/elrond-sdk-go-tools/releases/download/{TAG}/mcl_signer_{TAG}_macos-latest.tar.gz",
-        "dependencies.elrond_wasm_rs.tag": "v0.7.2.1",
+        "dependencies.elrond_wasm_rs.tag": "v0.10.2",
     }
 
 
