@@ -1,12 +1,11 @@
 
-from shutil import Error
 from typing import Any, Union
 
 
 class KnownError(Exception):
     inner = None
 
-    def __init__(self, message: str, inner: Union[Error, None] = None):
+    def __init__(self, message: str, inner: Union[Any, None] = None):
         super().__init__(message)
         self.inner = inner
 
@@ -32,8 +31,11 @@ class DownloadError(KnownError):
 
 
 class BadUrlError(DownloadError):
-    def __init__(self):
-        pass
+    pass
+
+
+class UnknownArchiveType(KnownError):
+    pass
 
 
 class DependencyMissing(KnownError):
@@ -51,6 +53,11 @@ class BadDirectory(KnownError):
         super().__init__(f"Bad directory: {directory}")
 
 
+class BadFile(KnownError):
+    def __init__(self, filename: str, inner=None):
+        super().__init__(f"Bad file: {filename}.", inner)
+
+
 class NotSupportedProject(KnownError):
     def __init__(self, directory: str):
         super().__init__(f"Directory is not a supported project: {directory}")
@@ -113,6 +120,16 @@ class UnknownConfigurationError(KnownError):
         super().__init__(f"Configuration entry is not known: {name}.")
 
 
+class ConfigurationShouldBeUniqueError(KnownError):
+    def __init__(self, name: str):
+        super().__init__(f"Configuration entry already exists: {name}.")
+
+
+class ConfigurationProtectedError(KnownError):
+    def __init__(self, name: str):
+        super().__init__(f"This configuration name is protected: {name}.")
+
+
 class UnknownDerivationFunction(KnownError):
     def __init__(self):
         super().__init__("Unknown key derivation function.")
@@ -133,6 +150,11 @@ class BadUserInput(KnownError):
         super().__init__(f"Bad user input: {message}.")
 
 
+class BadUsage(KnownError):
+    def __init__(self, message: str):
+        super().__init__(f"Bad usage: {message}.")
+
+
 class CannotSignMessageWithBLSKey(KnownError):
     def __init__(self):
         super(CannotSignMessageWithBLSKey, self).__init__("cannot sign message with BLS key")
@@ -151,3 +173,8 @@ class TransactionIsNotSigned(KnownError):
 class NoWalletProvided(KnownError):
     def __init__(self):
         super().__init__("No wallet provided.")
+
+
+class TestnetError(KnownError):
+    def __init__(self, message: str):
+        super().__init__(message)
