@@ -7,6 +7,7 @@ from erdpy import errors, utils
 from erdpy.projects import shared
 from erdpy.projects.project_rust import CargoFile
 from erdpy.projects.templates_config import get_templates_repositories
+from erdpy.testnet import wallets
 
 logger = logging.getLogger("projects.templates")
 
@@ -55,6 +56,10 @@ def create_from_template(name: str, template_name: str, directory: str):
 
     logger.info("Project created, template applied.")
 
+    wallets.copy_all_to(path.join(project_directory, "wallets"))
+
+    logger.info("Test wallets have been copied into the project.")
+
 
 def _download_templates_repositories():
     for repo in get_templates_repositories():
@@ -104,11 +109,11 @@ class TemplateRust(Template):
         logger.info("Patching cargo files...")
         self._patch_cargo()
         self._patch_cargo_wasm()
-        self._patch_cargo_debug()
+        self._patch_cargo_abi()
 
         logger.info("Patching source code...")
         self._patch_source_code_wasm()
-        self._patch_source_code_debug()
+        self._patch_source_code_abi()
         self._patch_source_code_tests()
 
         logger.info("Patching test files...")
@@ -119,12 +124,15 @@ class TemplateRust(Template):
 
         cargo_file = CargoFile(cargo_path)
         cargo_file.package_name = self.project_name
-        cargo_file.version = "0.0.1"
+        cargo_file.version = "0.0.0"
         cargo_file.authors = ["you"]
         cargo_file.edition = "2018"
+        cargo_file.publish = False
 
         for dependency in cargo_file.get_dependencies().values():
             del dependency["path"]
+        for dependency in cargo_file.get_dev_dependencies().values():
+            del dependency["path"]
 
         cargo_file.save()
 
@@ -133,12 +141,18 @@ class TemplateRust(Template):
 
         cargo_file = CargoFile(cargo_path)
         cargo_file.package_name = f"{self.project_name}-wasm"
-        cargo_file.version = "0.0.1"
+        cargo_file.version = "0.0.0"
         cargo_file.authors = ["you"]
         cargo_file.edition = "2018"
+        cargo_file.publish = False
 
         for dependency in cargo_file.get_dependencies().values():
             del dependency["path"]
+        # Currently, the following logic is not really needed (we don't have dev-dependencies in wasm/Cargo.toml):
+        for dependency in cargo_file.get_dev_dependencies().values():
+            del dependency["path"]
+
+        # Patch the path towards the project crate (one folder above):
         cargo_file.get_dependency(self.template_name)["path"] = ".."
 
         cargo_file.save()
@@ -150,25 +164,30 @@ class TemplateRust(Template):
             ]
         )
 
-    def _patch_cargo_debug(self):
-        cargo_debug_path = path.join(self.directory, "debug", TemplateRust.CARGO_TOML)
-        if not path.exists(cargo_debug_path):
+    def _patch_cargo_abi(self):
+        cargo_path = path.join(self.directory, "abi", TemplateRust.CARGO_TOML)
+        if not path.isfile(cargo_path):
             return
 
-        cargo_file_debug = CargoFile(cargo_debug_path)
-        cargo_file_debug.package_name = f"{self.project_name}-debug"
-        cargo_file_debug.version = "0.0.1"
-        cargo_file_debug.authors = ["you"]
-        cargo_file_debug.edition = "2018"
+        cargo_file = CargoFile(cargo_path)
+        cargo_file.package_name = f"{self.project_name}-abi"
+        cargo_file.version = "0.0.0"
+        cargo_file.authors = ["you"]
+        cargo_file.edition = "2018"
+        cargo_file.publish = False
 
-        for dependency in cargo_file_debug.get_dependencies().values():
+        for dependency in cargo_file.get_dependencies().values():
+            del dependency["path"]
+        for dependency in cargo_file.get_dev_dependencies().values():
             del dependency["path"]
-        cargo_file_debug.get_dependency(self.template_name)["path"] = ".."
 
-        cargo_file_debug.save()
+        # Patch the path towards the project crate (one folder above):
+        cargo_file.get_dependency(self.template_name)["path"] = ".."
+
+        cargo_file.save()
 
         self._replace_in_files(
-            [cargo_debug_path],
+            [cargo_path],
             [
                 (f"[dependencies.{self.template_name}]", f"[dependencies.{self.project_name}]")
             ]
@@ -184,13 +203,13 @@ class TemplateRust(Template):
             ]
         )
 
-    def _patch_source_code_debug(self):
-        debug_main_path = path.join(self.directory, "debug", "src", "main.rs")
-        if not path.exists(debug_main_path):
+    def _patch_source_code_abi(self):
+        abi_main_path = path.join(self.directory, "abi", "src", "main.rs")
+        if not path.exists(abi_main_path):
             return
 
         self._replace_in_files(
-            [debug_main_path],
+            [abi_main_path],
             [
                 # Example: replace "use simple-erc20::*" to "use my_token::*"
                 (f"use {self.template_name.replace('-', '_')}::*", f"use {self.project_name.replace('-', '_')}::*")
@@ -209,7 +228,7 @@ class TemplateRust(Template):
                 # Example: replace "use simple-erc20::*" to "use my_token::*"
                 (f"use {self.template_name.replace('-', '_')}::*", f"use {self.project_name.replace('-', '_')}::*"),
                 # Example: replace "extern crate adder;" to "extern crate myadder"
-                (f"extern crate {self.template_name.replace('-', '_')};", f"extern create {self.project_name.replace('-', '_')};")
+                (f"extern crate {self.template_name.replace('-', '_')};", f"extern crate {self.project_name.replace('-', '_')};")
             ]
         )
 
