@@ -1,7 +1,7 @@
 import logging
+import time
 from typing import Any, List, Tuple
 
-from erdpy import transactions, utils
 from erdpy.accounts import Address
 from erdpy.proxy.http_facade import do_get, do_post
 from erdpy.proxy.messages import NetworkConfig
@@ -46,6 +46,14 @@ class ElrondProxy:
             transaction["data"] = data
         return transactions
 
+    def get_esdt_tokens(self, address: str) -> List:
+        response = do_get(f"{self.url}/address/{address}/esdt")
+        return response.get("tokens")
+
+    def get_esdt_balance(self, address: str, ticker: str) -> dict:
+        response = do_get(f"{self.url}/address/{address}/esdt/{ticker}")
+        return response.get("tokenData")
+
     def get_num_shards(self):
         network_config = self.get_network_config()
         return network_config.num_shards
@@ -104,13 +112,14 @@ class ElrondProxy:
         response = do_post(url, payload)
         return response
 
-    def get_transaction(self, tx_hash: str, sender_address: str = "") -> Any:
+    def get_transaction(self, tx_hash: str, sender_address: str = "", with_results: bool = False) -> Any:
         url = f"{self.url}/transaction/{tx_hash}"
-        if sender_address:
-            url = f"{self.url}/transaction/{tx_hash}?sender={sender_address}"
+        url += f"?sender={sender_address or ''}"
+        url += f"&withResults={with_results}"
 
         response = do_get(url)
         transaction = response.get("transaction", dict())
+        transaction['hash'] = tx_hash
         return transaction
 
     def get_hyperblock(self, key) -> Any:
@@ -119,4 +128,27 @@ class ElrondProxy:
             url = f"{self.url}/hyperblock/by-nonce/{key}"
 
         response = do_get(url)
+        response = response.get("hyperblock", {})
         return response
+
+    def send_transaction_and_wait_for_result(self, payload: Any, num_seconds_timeout=100) -> str:
+        url = f"{self.url}/transaction/send"
+        response = do_post(url, payload)
+        tx_hash = response.get("txHash")
+
+        for _ in range(0, num_seconds_timeout):
+            if self.is_transaction_finalized(tx_hash):
+                return self.get_transaction(tx_hash=tx_hash, with_results=True)
+            time.sleep(1)
+        return ""
+
+    def is_transaction_finalized(self, tx_hash):
+        last_nonce = self.get_last_block_nonce("metachain")
+        last_hyperblock = self.get_hyperblock(last_nonce)
+        finalized_transactions = last_hyperblock["transactions"]
+
+        for transaction in finalized_transactions:
+            if transaction["hash"] == tx_hash:
+                return True
+
+        return False
