@@ -52,7 +52,7 @@ class TestnetConfiguration:
             # If the user has not specified a custom source repository, the
             # ones provided by the SDK will be used, which are downloaded as
             # tar.gz files from GitHub. Due to how the name of the archive is
-            # built by GitHub, the folder will contain the tag in two variants:
+            # built by GitHub, the path will contain the tag in two variants:
             # with the 'v' prefix (e.g. "v1.1.0"), but also without (e.g.
             # "1.1.0"), hence the need for {NOvTAG}.
             if default_tag.startswith("v"):
@@ -96,14 +96,13 @@ class TestnetConfiguration:
             if not filename.exists():
                 return dict()
 
-        logger.info('using local testnet config from %s', filename)
         return utils.read_toml_file(filename)
 
     @classmethod
     def get_sdk_testnet_config(cls):
         default = cls.default()
         filename = workstation.get_tools_folder() / "testnet.toml"
-        logger.info('sdk_testnet_config filename %s', filename)
+
         if not filename.exists():
             logger.info('writing sdk_testnet_config from defaults')
             utils.write_toml_file(str(filename), default)
@@ -272,12 +271,17 @@ class TestnetConfiguration:
     def loglevel(self):
         return self.features.get("loglevel", "")
 
+    def arwen_binary(self):
+        return self.features.get("arwen_binary")
+
+
     @classmethod
     def default(cls):
         config = dict()
         config['features'] = {
             'loglevel': '*:DEBUG',
             'proxy': True,
+            'arwen_binary': True
         }
         config['folders'] = {
             'elrond_go':
