@@ -185,6 +185,10 @@ def copy_config_to_proxy(testnet_config: TestnetConfiguration):
         proxy_config_source / 'config.toml',
         proxy_config)
 
+    shutil.copytree(
+        proxy_config_source / 'apiConfig',
+        proxy_config / 'apiConfig')
+
     shutil.copy(
         proxy_config_source / 'external.toml',
         proxy_config)
@@ -203,9 +207,16 @@ def patch_proxy_config(testnet_config: TestnetConfiguration):
     data['GeneralSettings']['ServerPort'] = testnet_config.proxy_port()
     utils.write_toml_file(proxy_config_file, data)
 
+    api_config_file = path.join(testnet_config.proxy_config_folder(), 'apiConfig', 'v1_0.toml')
+    data = utils.read_toml_file(api_config_file)
+    routes = data['APIPackages']['transaction']['Routes']
+    for route in routes:
+        route["Open"] = True
+    utils.write_toml_file(api_config_file, data)
 
-def makefolder(path):
-    path.mkdir(parents=True, exist_ok=True)
+
+def makefolder(path_where_to_make_folder):
+    path_where_to_make_folder.mkdir(parents=True, exist_ok=True)
 
 
 def patch_source_code(testnet_config: TestnetConfiguration):
@@ -215,7 +226,6 @@ def patch_source_code(testnet_config: TestnetConfiguration):
 
     file = path.join(folder, "core/constants.go")
     content = utils.read_file(file)
-    content = content.replace("const MaxNumShards = 256", "const MaxNumShards = 4")
     utils.write_file(file, content)
 
     file = path.join(folder, "cmd/node/main.go")
@@ -237,11 +247,14 @@ def build_binaries(testnet_config: TestnetConfiguration):
     node_folder = testnet_config.node_source() / "cmd" / "node"
     myprocess.run_process(['go', 'build'], cwd=node_folder, env=golang_env)
 
-    logger.info("Building arwen...")
-    node_folder_root = testnet_config.node_source()
-    env = dict(golang_env)
-    env["ARWEN_PATH"] = node_folder
-    myprocess.run_process(['make', 'arwen'], cwd=node_folder_root, env=env)
+    arwen_binary = testnet_config.arwen_binary()
+    logger.info("Arwen Binary: "+arwen_binary)
+    if arwen_binary:
+        logger.info("Building arwen...")
+        node_folder_root = testnet_config.node_source()
+        env = dict(golang_env)
+        env["ARWEN_PATH"] = node_folder
+        myprocess.run_process(['make', 'arwen'], cwd=node_folder_root, env=env)
 
     logger.info("Building proxy...")
     proxy_folder = testnet_config.proxy_source() / "cmd" / "proxy"
@@ -263,6 +276,8 @@ def build_binaries(testnet_config: TestnetConfiguration):
             shutil.copy(libwasmer_path, destination)
 
     shutil.copy(proxy_folder / "proxy", testnet_config.proxy_folder())
+    if workstation.get_platform() == "osx":
+        shutil.copy(libwasmer_path, testnet_config.proxy_folder())
 
 
 def _get_arwen_version(testnet_config: TestnetConfiguration):
